@@ -2,7 +2,7 @@ import sys,os
 sys.path.append('.')
 import pickle,numpy as np
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 __author__ = 'Jakob Lass'
 
 # installFolder = os.path.abspath(os.path.split(__file__)[0])
@@ -26,12 +26,4 @@ except FileNotFoundError:
     foundFile = str(find('calibrationDict.dat',os.path.abspath(os.path.join(installFolder,'..','..','..','..','..','..')))[0])
 
     with open(foundFile,'rb') as f:
-        calibrationDict = pickle.load(f)
-    #raise FileNotFoundError
-
-    
-calib2021 = {'limits':np.array([1]),
-             'names':np.array(['Mockup']),
-             'Mockup':np.ones((1152,128))}
-
-calibrationDict[2021] = calib2021
\ No newline at end of file
+        calibrationDict = pickle.load(f)
\ No newline at end of file
